==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/intune/kotlin/inputs/GetIoMAMPolicyByNamePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.intune.kotlin.inputs

import com.pulumi.azurenative.intune.inputs.GetIoMAMPolicyByNamePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hostName Location hostName for the tenant
 * @property policyName Unique name for the policy
 * @property select select specific fields in entity.
 */
public data class GetIoMAMPolicyByNamePlainArgs(
    public val hostName: String,
    public val policyName: String,
    public val select: String? = null,
) : ConvertibleToJava<com.pulumi.azurenative.intune.inputs.GetIoMAMPolicyByNamePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.intune.inputs.GetIoMAMPolicyByNamePlainArgs =
        com.pulumi.azurenative.intune.inputs.GetIoMAMPolicyByNamePlainArgs.builder()
            .hostName(hostName.let({ args0 -> args0 }))
            .policyName(policyName.let({ args0 -> args0 }))
            .select(select?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetIoMAMPolicyByNamePlainArgs].
 */
@PulumiTagMarker
public class GetIoMAMPolicyByNamePlainArgsBuilder internal constructor() {
    private var hostName: String? = null

    private var policyName: String? = null

    private var select: String? = null

    /**
     * @param value Location hostName for the tenant
     */
    @JvmName("thxwiblxjlskqtyt")
    public suspend fun hostName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hostName = mapped
    }

    /**
     * @param value Unique name for the policy
     */
    @JvmName("intyksvsrdqtlaie")
    public suspend fun policyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.policyName = mapped
    }

    /**
     * @param value select specific fields in entity.
     */
    @JvmName("ywnvorstcfhrmjsb")
    public suspend fun select(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.select = mapped
    }

    internal fun build(): GetIoMAMPolicyByNamePlainArgs = GetIoMAMPolicyByNamePlainArgs(
        hostName = hostName ?: throw PulumiNullFieldException("hostName"),
        policyName = policyName ?: throw PulumiNullFieldException("policyName"),
        select = select,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/intune/kotlin/inputs/GetIoMAMPolicyByNamePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.intune.kotlin.inputs

import com.pulumi.azurenative.intune.inputs.GetIoMAMPolicyByNamePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hostName Location hostName for the tenant
 * @property policyName Unique name for the policy
 * @property select select specific fields in entity.
 */
public data class GetIoMAMPolicyByNamePlainArgs(
    public val hostName: String,
    public val policyName: String,
    public val select: String? = null,
) : ConvertibleToJava<com.pulumi.azurenative.intune.inputs.GetIoMAMPolicyByNamePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.intune.inputs.GetIoMAMPolicyByNamePlainArgs =
        com.pulumi.azurenative.intune.inputs.GetIoMAMPolicyByNamePlainArgs.builder()
            .hostName(hostName.let({ args0 -> args0 }))
            .policyName(policyName.let({ args0 -> args0 }))
            .select(select?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetIoMAMPolicyByNamePlainArgs].
 */
@PulumiTagMarker
public class GetIoMAMPolicyByNamePlainArgsBuilder internal constructor() {
    private var hostName: String? = null

    private var policyName: String? = null

    private var select: String? = null

    /**
     * @param value Location hostName for the tenant
     */
    @JvmName("vcewnspxdleihtov")
    public suspend fun hostName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hostName = mapped
    }

    /**
     * @param value Unique name for the policy
     */
    @JvmName("mjfuyecnhsrstlnd")
    public suspend fun policyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.policyName = mapped
    }

    /**
     * @param value select specific fields in entity.
     */
    @JvmName("qvrdgusidubstfyc")
    public suspend fun select(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.select = mapped
    }

    internal fun build(): GetIoMAMPolicyByNamePlainArgs = GetIoMAMPolicyByNamePlainArgs(
        hostName = hostName ?: throw PulumiNullFieldException("hostName"),
        policyName = policyName ?: throw PulumiNullFieldException("policyName"),
        select = select,
    )
}
